@@ -8,21 +8,18 @@
  *
  * @version @package_version@
  * @author Kris Steinhoff
+ * @license GNU GPLv3+
  *
  * Example configuration:
  *
  *  // The id of the address book to use to automatically set a new
  *  // user's full name in their new identity. (This should be an
- *  // string, which refers to the $rcmail_config['ldap_public'] array.)
- *  $rcmail_config['new_user_identity_addressbook'] = 'People';
+ *  // string, which refers to the $config['ldap_public'] array.)
+ *  $config['new_user_identity_addressbook'] = 'People';
  *
  *  // When automatically setting a new users's full name in their
  *  // new identity, match the user's login name against this field.
- *  $rcmail_config['new_user_identity_match'] = 'uid';
- *
- *  // Use this field (from fieldmap configuration) to fill alias col of
- *  // the new user record.
- *  $rcmail_config['new_user_identity_alias'] = 'alias';
+ *  $config['new_user_identity_match'] = 'uid';
  */
 class new_user_identity extends rcube_plugin
 {
@@ -37,8 +34,6 @@ class new_user_identity extends rcube_plugin
 
     function lookup_user_name($args)
     {
-        $rcmail = rcmail::get_instance();
-
         if ($this->init_ldap($args['host'])) {
             $results = $this->ldap->search('*', $args['user'], true);
             if (count($results->records) == 1) {
@@ -47,10 +42,7 @@ class new_user_identity extends rcube_plugin
 
                 $args['user_name'] = $user_name;
                 if (!$args['user_email'] && strpos($user_email, '@')) {
-                    $args['user_email'] = rcube_idn_to_ascii($user_email);
-                }
-                if (($alias_col = $rcmail->config->get('new_user_identity_alias')) && $results->records[0][$alias_col]) {
-                  $args['alias'] = is_array($results->records[0][$alias_col]) ? $results->records[0][$alias_col][0] : $results->records[0][$alias_col];
+                    $args['user_email'] = rcube_utils::idn_to_ascii($user_email);
                 }
             }
         }
